# lmflux

A library for managing agentic LLM workflows.

## Overview

`lmflux` provides a declarative framework fow executing LLM-based flows and multi-agent setups.

## Installation

```bash
pip install lmflux
```

## Documentation

Examples and documentation is available at https://lmflux.readthedocs.io/en/latest/.

## License

This project is licensed under the MIT License.